You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficcontrol.apache.org by sh...@apache.org on 2019/06/24 01:40:45 UTC

[trafficcontrol] 01/02: CDN-in-a-Box now uses Snapshots instead of legacy CRConfig

This is an automated email from the ASF dual-hosted git repository.

shihta pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficcontrol.git

commit c0578cf8f8b613d71250c3a0d78c2830d838e18b
Author: ocket8888 <oc...@gmail.com>
AuthorDate: Thu Jun 20 10:26:54 2019 -0600

    CDN-in-a-Box now uses Snapshots instead of legacy CRConfig
---
 infrastructure/cdn-in-a-box/README.md              | 4 ++--
 infrastructure/cdn-in-a-box/traffic_monitor/run.sh | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/infrastructure/cdn-in-a-box/README.md b/infrastructure/cdn-in-a-box/README.md
index af21634..0a79957 100644
--- a/infrastructure/cdn-in-a-box/README.md
+++ b/infrastructure/cdn-in-a-box/README.md
@@ -166,9 +166,9 @@ To expose the ports of each service on the host, add the `docker-compose.expose-
 
 If you scroll back through the output ( or use `docker-compose logs trafficops-perl | grep "User defined signal 2"` ) and see a line that says something like `/run.sh: line 79: 118 User defined signal 2 $TO_DIR/local/bin/hypnotoad script/cdn` then you've hit a mysterious known error. We don't know what this is or why it happens, but your best bet is to send up a quick prayer and restart the stack.
 
-### Traffic Monitor is stuck waiting for a valid CRConfig 
+### Traffic Monitor is stuck waiting for a valid Snapshot
 
-Often times you must snap the CDN in order for a valid CRConfig to be generated. This can be done by logging into the Traffic Portal and clicking the camera icon, then clicking the perform snapshot button.
+Often times you must take a CDN [Snapshot](https://traffic-control-cdn.readthedocs.io/en/latest/glossary.html#term-snapshot) in order for a valid Snapshot to be generated. This can be done through [Traffic Portal's "CDNs" view](https://traffic-control-cdn.readthedocs.io/en/latest/admin/traffic_portal/usingtrafficportal.html#cdns), clicking on the "CDN-in-a-Box" CDN, then pressing the camera button, and finally the "Perform Snapshot" button.
 
 ### I'm seeing a failure to open a socket and/or set a socket option
 
diff --git a/infrastructure/cdn-in-a-box/traffic_monitor/run.sh b/infrastructure/cdn-in-a-box/traffic_monitor/run.sh
index b40bfc6..7aba9c8 100755
--- a/infrastructure/cdn-in-a-box/traffic_monitor/run.sh
+++ b/infrastructure/cdn-in-a-box/traffic_monitor/run.sh
@@ -103,10 +103,10 @@ export TO_PASSWORD=$TO_ADMIN_PASSWORD
 
 touch /opt/traffic_monitor/var/log/traffic_monitor.log
 
-# Do not start until there is a valid CRConfig available
-until [ $(to-get "/CRConfig-Snapshots/$CDN_NAME/CRConfig.json" 2>/dev/null | jq -c -e '.config|length') -gt 0 ] ; do
-	echo "Waiting on valid CRConfig..."; 
-  	sleep 3; 
+# Do not start until there a valid Snapshot has been taken
+until [ $(to-get "/api/1.4/cdns/$CDN_NAME/snapshot" 2>/dev/null | jq -c -e '.config|length') -gt 0 ] ; do
+	echo "Waiting on valid Snapshot...";
+  	sleep 3;
 done
 
 cd /opt/traffic_monitor